
Missing authentication or authorization
-------

**Description:**
If pages are not properly checked for authentication or authorization, an attacker could 
abuse these flaws. The consequences are differ per application but may lead to 
high risk vulnerabilities.


**Solution:**
The application should check pages or functionality based on authentication and authorization.

	